OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Nurodytas operatorius yra neteisingas",
    "The given regular expression is invalid" : "Nurodytas reguliarusis reiškinys yra neteisingas",
    "The given file size is invalid" : "Nurodytas failo dydis yra neteisingas",
    "The given tag id is invalid" : "Nurodytas žymos id yra neteisingas",
    "The given IP range is invalid" : "Nurodytas IP rėžis yra neteisingas",
    "The given IP range is not valid for IPv4" : "Nurodytas IPv4 adresas neteisingas",
    "The given IP range is not valid for IPv6" : "Nurodytas IPv6 adresas neteisingas",
    "The given time span is invalid" : "Neteisingai nurodytas laiko tarpsnis",
    "The given start time is invalid" : "Neteisingai nurodyta laiko pradžia",
    "The given end time is invalid" : "Neteisingai nurodyta laiko pabaiga",
    "The given group does not exist" : "Pateikta grupė neegzistuoja",
    "File" : "Failas",
    "File created" : "Failas sukurtas",
    "File updated" : "Failas atnaujintas",
    "File renamed" : "Failas pervadintas",
    "File deleted" : "Failas ištrintas",
    "File accessed" : "Gauta prieiga prie failo",
    "File copied" : "Failas nukopijuotas",
    "Tag assigned" : "Priskirta žyma",
    "Someone" : "Kažkas",
    "%s created %s" : "%s sukūrė %s",
    "%s modified %s" : "%s modifikavo %s",
    "%s deleted %s" : "%s ištrynė %s",
    "%s accessed %s" : "%s pasiekiamas %s",
    "%s renamed %s" : "%s pervadino %s",
    "%s copied %s" : "%s nukopijavo %s",
    "Operation #%s does not exist" : "Operacijos #%s nėra",
    "Entity %s does not exist" : "Subjektas %s neegzistuoja",
    "Entity %s is invalid" : "Subjektas %s yra neteisingas",
    "No events are chosen." : "Nepasirinkta jokių įvykių.",
    "Entity %s has no event %s" : "Subjektas %s neturi įvykių %s",
    "Operation %s does not exist" : "Operacijos %s nėra",
    "Operation %s is invalid" : "Neteisinga %s operacija",
    "At least one check needs to be provided" : "Privalo būti nurodytas bent vienas patikrinimas",
    "Invalid check provided" : "Nurodytas neteisingas payikrinimas",
    "Check %s does not exist" : "Patikrinimas %s neegzistuoja",
    "Check %s is invalid" : "Patikrinimas %s yra neteisingas",
    "Check %s is not allowed with this entity" : "%s yra negalimas šiam subjektui",
    "Check #%s does not exist" : "Patikrinimas #%s neegzistuoja",
    "Check %s is invalid or does not exist" : "%s neteisingas arba neegzistuoja",
    "Flow" : "Eiga",
    "Nextcloud workflow engine" : "Nextcloud darbo eigos modulis",
    "Select a filter" : "Pasirinkite filtrą",
    "Select a comparator" : "Pasirinkite palyginimą",
    "Remove filter" : "Šalinti filtrą",
    "Audio" : "Garso įrašai",
    "Folder" : "Aplankas",
    "Images" : "Paveikslai",
    "Office documents" : "Raštinės dokumentai",
    "PDF documents" : "PDF dokumentai",
    "Custom MIME type" : "Tinkintas MIME tipas",
    "Select a file type" : "Pasirinkite failo tipą",
    "e.g. httpd/unix-directory" : "pvz., httpd/unix-directory",
    "Please enter a valid time span" : "Įveskite teisingą laiko intervalą",
    "Files WebDAV" : "WebDAV failai",
    "Custom URL" : "Tinkintas URL",
    "Select a request URL" : "Pasirinkite užklausos URL",
    "Android client" : "Android klientas",
    "iOS client" : "iOS klientas",
    "Desktop client" : "Darbalaukio klientas",
    "Thunderbird & Outlook addons" : "Thunderbird ir Outlook priedai",
    "Custom user agent" : "Tinkintas naudotojo agentas",
    "Select a user agent" : "Pasirinkite naudotojo agentą",
    "Select groups" : "Pasirinkti grupes",
    "Groups" : "Grupės",
    "At least one event must be selected" : "Privalo būti pasirinktas bent vienas įvykis",
    "Add new flow" : "Pridėti naują eigą",
    "The configuration is invalid" : "Konfigūracija yra neteisinga",
    "Active" : "Aktyvi",
    "Save" : "Įrašyti",
    "When" : "Kada",
    "and" : "ir",
    "Add a new filter" : "Pridėti naują filtrą",
    "Cancel" : "Atsisakyti",
    "Delete" : "Ištrinti",
    "Available flows" : "Prieinamos eigos",
    "For details on how to write your own flow, check out the development documentation." : "Išsamesnę informaciją apie tai, kaip parašyti savo asmeninę eigą, rasite plėtotojo dokumentacijoje.",
    "More flows" : "Daugiau eigų",
    "Browse the App Store" : "Naršyti programėlių parduotuvę",
    "Show less" : "Rodyti mažiau",
    "Show more" : "Rodyti daugiau",
    "Configured flows" : "Konfigūruotos eigos",
    "Your flows" : "Jūsų eigos",
    "matches" : "atitinka",
    "does not match" : "neatitinka",
    "is" : "yra",
    "is not" : "nėra",
    "File name" : "Failo pavadinimas",
    "File MIME type" : "Failo MIME tipas",
    "File size (upload)" : "Failo dydis (įkėlimas)",
    "less" : "mažiau",
    "less or equals" : "mažiau arba lygu",
    "greater or equals" : "daugiau arba lygu",
    "greater" : "daugiau",
    "Request remote address" : "Užklausti nuotolinį adresą",
    "matches IPv4" : "atitinka IPv4",
    "does not match IPv4" : "neatitinka IPv4",
    "matches IPv6" : "atitinka IPv6",
    "does not match IPv6" : "neatitinka IPv6",
    "File system tag" : "Failų sistemos žyma",
    "is tagged with" : "pažymėtas",
    "is not tagged with" : "nepažymėtas",
    "Request URL" : "Užklausos URL",
    "Request time" : "Užklausos laikas",
    "between" : "tarp",
    "not between" : "nėra tarp",
    "Request user agent" : "Užklausti naudotojo agentą",
    "is member of" : "priklauso grupei",
    "is not member of" : "nepriklauso grupei",
    "Type to search for group …" : "Rašykite norėdami ieškoti grupės…"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
